<?php
namespace Bushelpowered\Api\Grain\Contracts\V1\Model;
        
class PricingHistoryRaw implements \Bushelpowered\Api\Common\Event\RawRecord, \Bushelpowered\Api\Common\HasSourceTimestamps, \Bushelpowered\Api\Common\Event\Syncable
{
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var string $sourcePricingLineId The source pricing line identifier.*/
    public string $sourcePricingLineId;
    /** @var string $pricingLineIntegrationId The pricing line integration identifier.*/
    public string $pricingLineIntegrationId;
    /** @var null|string $sourceType A name or reason for the pricing event, such as freight charge or tax.*/
    public ?string $sourceType = null;
    /** @var null|float $sourcePrice The monetary effect of this event.*/
    public ?float $sourcePrice = null;
    /** @var null|string $sourcePricingMode The modality by which pricing is affected, primarily flat or per-unit.*/
    public ?string $sourcePricingMode = null;
    /** @var null|string $sourceAccountId The datasource's remote id of the account that owns this record, if any.*/
    public ?string $sourceAccountId = null;
    /** @var null|string $sourceLocationId The datasource's remote id of the location that owns this record, if any.*/
    public ?string $sourceLocationId = null;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var null|string $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  string  $sourcePricingLineId The source pricing line identifier.
     * @param  string  $pricingLineIntegrationId The pricing line integration identifier.
     * @param  null|string  $sourceType A name or reason for the pricing event, such as freight charge or tax.
     * @param  null|float  $sourcePrice The monetary effect of this event.
     * @param  null|string  $sourcePricingMode The modality by which pricing is affected, primarily flat or per-unit.
     * @param  null|string  $sourceAccountId The datasource's remote id of the account that owns this record, if any.
     * @param  null|string  $sourceLocationId The datasource's remote id of the location that owns this record, if any.
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $tenantId, string $datasourceId, string $integrationId, string $sourceId, string $sourcePricingLineId, string $pricingLineIntegrationId, ?string $sourceType, ?float $sourcePrice, ?string $sourcePricingMode, ?string $sourceAccountId, ?string $sourceLocationId, string $sourceUpdatedAt, string $sourceCreatedAt, ?string $sourceDeletedAt)
    {
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourcePricingLineId = $sourcePricingLineId;
        $this->pricingLineIntegrationId = $pricingLineIntegrationId;
        $this->sourceType = $sourceType;
        $this->sourcePrice = $sourcePrice;
        $this->sourcePricingMode = $sourcePricingMode;
        $this->sourceAccountId = $sourceAccountId;
        $this->sourceLocationId = $sourceLocationId;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The datasource's remote id of the account that owns this record, if any.
     */
    public function getSourceAccountId(): ?string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return null|string The datasource's remote id of the location that owns this record, if any.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}